FlutterAdvancedHtmlEditor class

Main HTML editor widget

A comprehensive rich text editor that combines a WebView-based editing area with a customizable toolbar for formatting and content management.

Inheritance

Constructors

FlutterAdvancedHtmlEditor({Key? key, required HtmlEditorController controller, String initialContent = '', double height = 400, required HtmlEditorTheme theme, dynamic onContentChanged(String)?, dynamic onSelectionChanged(Map<String, dynamic>)?, bool showToolbar = true, List<HtmlEditorToolbarItem>? customToolbarItems, BoxDecoration? boxDecoration, BoxDecoration? errorBoxDecoration, double? borderRadius, Widget? loadingWidget, int? maxLength, int? minLength, String? hintText, dynamic onLimitExceeded(String)?, bool enabled = true, int? minLines})
const

Properties

borderRadius double?
final
boxDecoration BoxDecoration?
final
controller HtmlEditorController
final
customToolbarItems List<HtmlEditorToolbarItem>?
final
enabled bool
final
errorBoxDecoration BoxDecoration?
final
hashCode int
The hash code for this object.
no setterinherited
height double
final
hintText String?
final
initialContent String
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loadingWidget Widget?
final
maxLength int?
final
minLength int?
final
minLines int?
final
onContentChanged → dynamic Function(String)?
final
onLimitExceeded → dynamic Function(String)?
final
onSelectionChanged → dynamic Function(Map<String, dynamic>)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showToolbar bool
final
theme HtmlEditorTheme
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<FlutterAdvancedHtmlEditor>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited